# emailapp package

## Submodules

## emailapp.asgi module

ASGI config for emailapp project.

It exposes the ASGI callable as a module-level variable named `application`.

For more information on this file, see https://docs.djangoproject.com/en/4.2/howto/deployment/asgi/

## emailapp.settings module

Django settings for emailapp project.

Generated by ‘django-admin startproject’ using Django 4.2.2.

For more information on this file, see https://docs.djangoproject.com/en/4.2/topics/settings/

For the full list of settings and their values, see https://docs.djangoproject.com/en/4.2/ref/settings/

## emailapp.urls module

### URL configuration for emailapp project.

The urlpatterns list routes URLs to views. For more information please see:

  https://docs.djangoproject.com/en/4.2/topics/http/urls/

Examples: Function views

> 1. Add an import: from my_app import views

> 2. Add a URL to urlpatterns: path(‘’, views.home, name=’home’)

Class-based views

  1. Add an import: from other_app.views import Home

  2. Add a URL to urlpatterns: path(‘’, Home.as_view(), name=’home’)

Including another URLconf

  1. Import the include() function: from django.urls import include, path

  2. Add a URL to urlpatterns: path(‘blog/’, include(‘blog.urls’))

## emailapp.wsgi module

WSGI config for emailapp project.

It exposes the WSGI callable as a module-level variable named `application`.

For more information on this file, see https://docs.djangoproject.com/en/4.2/howto/deployment/wsgi/

## Module contents